@@ -15,19 +15,19 @@
  */
 package org.jbpm.workbench.pr.client.editors.definition.list;
 
+import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_DEFINITION_ID;
+import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
+
 import java.util.List;
 import java.util.function.Predicate;
+
 import javax.enterprise.context.Dependent;
 import javax.enterprise.event.Event;
 import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
-import com.google.gwt.user.cellview.client.ColumnSortList;
-import com.google.gwt.view.client.Range;
 import org.jboss.errai.bus.client.api.messaging.Message;
 import org.jboss.errai.common.client.api.Caller;
-import org.jboss.errai.common.client.api.ErrorCallback;
-import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jbpm.workbench.common.client.PerspectiveIds;
 import org.jbpm.workbench.common.client.list.AbstractScreenListPresenter;
 import org.jbpm.workbench.common.client.list.ListView;
@@ -37,17 +37,19 @@ import org.jbpm.workbench.forms.client.display.providers.StartProcessFormDisplay
 import org.jbpm.workbench.forms.client.display.views.PopupFormDisplayerView;
 import org.jbpm.workbench.forms.display.api.ProcessDisplayerConfig;
 import org.jbpm.workbench.pr.client.resources.i18n.Constants;
+import org.jbpm.workbench.pr.events.NewCaseInstanceEvent;
 import org.jbpm.workbench.pr.events.NewProcessInstanceEvent;
 import org.jbpm.workbench.pr.events.ProcessDefSelectionEvent;
 import org.jbpm.workbench.pr.events.ProcessInstanceSelectionEvent;
 import org.jbpm.workbench.pr.model.ProcessDefinitionKey;
+import org.jbpm.workbench.pr.model.ProcessInstanceSummary;
 import org.jbpm.workbench.pr.model.ProcessSummary;
 import org.jbpm.workbench.pr.service.ProcessRuntimeDataService;
+import org.kie.workbench.common.workbench.client.error.DefaultWorkbenchErrorCallback;
 import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.annotations.WorkbenchScreen;
 import org.uberfire.client.mvp.UberView;
-import org.uberfire.ext.widgets.common.client.common.popups.errors.ErrorPopup;
 import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.security.ResourceRef;
@@ -56,8 +58,8 @@ import org.uberfire.workbench.model.ActivityResourceType;
 import org.uberfire.workbench.model.menu.MenuFactory;
 import org.uberfire.workbench.model.menu.Menus;
 
-import static org.jbpm.workbench.common.client.PerspectiveIds.SEARCH_PARAMETER_PROCESS_DEFINITION_ID;
-import static org.kie.workbench.common.workbench.client.PerspectiveIds.PROCESS_INSTANCES;
+import com.google.gwt.user.cellview.client.ColumnSortList;
+import com.google.gwt.view.client.Range;
 
 @Dependent
 @WorkbenchScreen(identifier = PerspectiveIds.PROCESS_DEFINITION_LIST_SCREEN)
@@ -75,6 +77,9 @@ public class ProcessDefinitionListPresenter extends AbstractScreenListPresenter<
     @Inject
     private Caller<ProcessRuntimeDataService> processRuntimeDataService;
 
+    @Inject
+    private DefaultWorkbenchErrorCallback errorCallback;
+
     protected AuthorizationManager authorizationManager;
 
     @Inject
@@ -116,12 +121,14 @@ public class ProcessDefinitionListPresenter extends AbstractScreenListPresenter<
 
     public void openGenericForm(final String processDefId,
                                 final String deploymentId,
-                                final String processDefName) {
+                                final String processDefName,
+                                final boolean isDynamic) {
 
         ProcessDisplayerConfig config = new ProcessDisplayerConfig(new ProcessDefinitionKey(getSelectedServerTemplate(),
                                                                                             deploymentId,
                                                                                             processDefId,
-                                                                                            processDefName),
+                                                                                            processDefName,
+                                                                                            isDynamic),
                                                                    processDefName);
 
         formDisplayPopUp.setTitle(processDefName);
@@ -159,41 +166,27 @@ public class ProcessDefinitionListPresenter extends AbstractScreenListPresenter<
         currentFilter.setOrderBy(columnSortList.size() > 0 ? columnSortList.get(0).getColumn().getDataStoreName() : "");
         currentFilter.setIsAscending(columnSortList.size() == 0 || columnSortList.get(0).isAscending());
 
-        processRuntimeDataService.call(new RemoteCallback<List<ProcessSummary>>() {
-                                           @Override
-                                           public void callback(final List<ProcessSummary> processDefsSums) {
-                                               boolean lastPageExactCount = processDefsSums.size() < visibleRange.getLength();
-                                               updateDataOnCallback(processDefsSums,
-                                                                    visibleRange.getStart(),
-                                                                    visibleRange.getStart() + processDefsSums.size(),
-                                                                    lastPageExactCount);
-                                           }
+        processRuntimeDataService.call((List<ProcessSummary> processDefsSums) -> {
+                                           boolean lastPageExactCount = processDefsSums.size() < visibleRange.getLength();
+                                           updateDataOnCallback(processDefsSums,
+                                                                visibleRange.getStart(),
+                                                                visibleRange.getStart() + processDefsSums.size(),
+                                                                lastPageExactCount);
                                        },
-                                       new ErrorCallback<Message>() {
-                                           @Override
-                                           public boolean error(Message message,
-                                                                Throwable throwable) {
-                                               return onRuntimeDataServiceError();
-                                           }
-                                       }).getProcesses(getSelectedServerTemplate(),
-                                                       visibleRange.getStart() / visibleRange.getLength(),
-                                                       visibleRange.getLength(),
-                                                       currentFilter.getOrderBy(),
-                                                       currentFilter.isAscending());
+                                       (Message message, Throwable throwable) -> onRuntimeDataServiceError(throwable)
+        ).getProcesses(getSelectedServerTemplate(),
+                       visibleRange.getStart() / visibleRange.getLength(),
+                       visibleRange.getLength(),
+                       currentFilter.getOrderBy(),
+                       currentFilter.isAscending());
     }
 
-    boolean onRuntimeDataServiceError() {
-        view.hideBusyIndicator();
-
-        showErrorPopup(constants.ResourceCouldNotBeLoaded(commonConstants.Process_Definitions()));
-
+    boolean onRuntimeDataServiceError(final Throwable throwable) {
+        setEmptyResults();
+        errorCallback.error(throwable);
         return false;
     }
 
-    void showErrorPopup(final String message) {
-        ErrorPopup.showMessage(message);
-    }
-
     @WorkbenchMenu
     public Menus buildMenu() {
         return MenuFactory
@@ -222,12 +215,29 @@ public class ProcessDefinitionListPresenter extends AbstractScreenListPresenter<
                               constants.ProcessInstanceBreadcrumb(newProcessInstance.getNewProcessInstanceId()),
                               PerspectiveIds.PROCESS_INSTANCE_DETAILS_SCREEN);
         placeManager.goTo(PerspectiveIds.PROCESS_INSTANCE_DETAILS_SCREEN);
-        processInstanceSelected.fire(new ProcessInstanceSelectionEvent(newProcessInstance.getDeploymentId(),
+        processInstanceSelected.fire(new ProcessInstanceSelectionEvent(newProcessInstance.getServerTemplateId(),
+                                                                       newProcessInstance.getDeploymentId(),
                                                                        newProcessInstance.getNewProcessInstanceId(),
-                                                                       newProcessInstance.getNewProcessDefId(),
-                                                                       newProcessInstance.getProcessDefName(),
-                                                                       newProcessInstance.getNewProcessInstanceStatus(),
-                                                                       newProcessInstance.getServerTemplateId()));
+                                                                       false));
+    }
+    
+    public void refreshNewCaseInstance(@Observes NewCaseInstanceEvent newCaseInstance) {
+                
+        processRuntimeDataService.call((ProcessInstanceSummary newProcessInstance) -> {
+            setupDetailBreadcrumb(placeManager,
+                                  commonConstants.Manage_Process_Definitions(),
+                                  constants.ProcessInstanceBreadcrumb(newProcessInstance.getId()),
+                                  PerspectiveIds.PROCESS_INSTANCE_DETAILS_SCREEN);
+            placeManager.goTo(PerspectiveIds.PROCESS_INSTANCE_DETAILS_SCREEN);
+            processInstanceSelected.fire(new ProcessInstanceSelectionEvent(newProcessInstance.getServerTemplateId(),
+                                                                           newProcessInstance.getDeploymentId(),
+                                                                           newProcessInstance.getId(),
+                                                                           false));
+            },
+            (Message message, Throwable throwable) -> onRuntimeDataServiceError(throwable)
+        ).getProcessInstanceByCorrelationKey(newCaseInstance.getServerTemplateId(), newCaseInstance.getNewCaseId());
+        
+        
     }
 
     public Predicate<ProcessSummary> getViewProcessInstanceActionCondition() {
@@ -235,7 +245,7 @@ public class ProcessDefinitionListPresenter extends AbstractScreenListPresenter<
     }
 
     public Predicate<ProcessSummary> getStartCondition() {
-        return processSummary -> !processSummary.isDynamic();
+        return processSummary -> !processSummary.isDynamic() || (processSummary.isDynamic() && processSummary.isDynamicFormsEnabled());
     }
 
     public void viewProcessInstances(String processDefId) {
